@@ -408,6 +408,15 @@ class Microservices(BaseClass, ABC):
         if not errorResp is None:
             errorCode = errorResp.get('errorCode', -99)  # Error generico
 
+        try:
+            errorCodeBk = errorCode
+            # Prevenir el paso de string como error
+            errorCode = int(errorCode)
+        except:
+            self.logs.error(
+                'Ocurrio une error al realizar el CAST del error code: {}'.format(errorCodeBk))
+            errorCode = -99
+
         # Validar si ocurrio un error
         if errorCode < 0 or errorCode > 0:
             # Estructura del mensaje de error
